# **Welcome to the OpenFL Tutorials!**
## The **Director Workflow** tutorials can be found in the "interactive_api" folder. All other tutorials are for the **Aggregator Workflow**.

<br/>

### The OpenFL tutorials cover a variety of frameworks, models, and datasets making them a great way to get started with OpenFL! 
